@@ -1,3 +1,4 @@
+import operator
 import os
 import re
 from enum import Enum
@@ -93,11 +94,14 @@ class ZeroShotClassifierAnnotator(AnnotatorBase):
 
 def compute_categories(result: dict, multi_label_threshold, multi_label=False) -> List[Category]:
     cats: List[Category] = []
-    for label, score in zip(result['labels'], result['scores']):
-        if score > multi_label_threshold:
-            cats.append(Category(label=label, labelName=sanitize_label(label), score=score))
-            if not multi_label:
-                break
+    if multi_label:
+        for label, score in zip(result['labels'], result['scores']):
+            if score > multi_label_threshold:
+                cats.append(Category(label=label, labelName=sanitize_label(label), score=score))
+    else:
+        index, score = max(enumerate(result['scores']), key=operator.itemgetter(1))
+        label = result['labels'][index]
+        cats.append(Category(label=label, labelName=sanitize_label(label), score=score))
     return cats
 
 
